summaryrefslogtreecommitdiffstats
path: root/xsetup.py
diff options
context:
space:
mode:
Diffstat (limited to 'xsetup.py')
-rw-r--r--xsetup.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/xsetup.py b/xsetup.py
index b4623c5f1..f5db25675 100644
--- a/xsetup.py
+++ b/xsetup.py
@@ -35,10 +35,11 @@ class XSetup:
# really all of this should be in rhpl probably
#
def write(self, fn, mouse, keyboard):
- #
- # always turn dri on
- #
- self.xhwstate.set_dri_enabled(1)
+ # always turn dri on FIXME: except on ia64
+ if iutil.getArch() == "ia64":
+ self.xhwstate.set_dri_enabled(0)
+ else:
+ self.xhwstate.set_dri_enabled(1)
#
# XXX - cleanup monitor name to not include 'DDC Probed Monitor'